@@ -37,10 +37,7 @@
 #'   a list of settings created with \code{\link{amText}}, or a list with two
 #'   fields: \code{text}, a list of settings created with \code{\link{amText}},
 #'   and \code{align}, can be \code{"left"}, \code{"right"} or \code{"center"}
-#' @param theme theme, \code{NULL} or one of \code{"dataviz"},
-#' \code{"material"}, \code{"kelly"}, \code{"dark"}, \code{"moonrisekingdom"},
-#' \code{"frozen"}, \code{"spiritedaway"}, \code{"patterns"},
-#' \code{"microchart"}
+#' @template themeTemplate
 #' @param draggable \code{TRUE}/\code{FALSE} to enable/disable dragging of
 #'   all bullets, otherwise a named list of the form
 #'   \code{list(value1 = TRUE, value2 = FALSE, ...)}
@@ -186,6 +183,7 @@ amHorizontalDumbbellChart <- function(
   valueFormatter = "#.",
   chartTitle = NULL,
   theme = NULL,
+  animated = TRUE,
   draggable = FALSE,
   tooltip = NULL, # default
   segmentsStyle = NULL, # default
@@ -569,6 +567,7 @@ amHorizontalDumbbellChart <- function(
       valueFormatter = valueFormatter,
       chartTitle = chartTitle,
       theme = theme,
+      animated = animated,
       draggable = draggable,
       tooltip = tooltip,
       segmentsStyle = segmentsStyle,
