@@ -106,10 +106,7 @@
 #'   a list of settings created with \code{\link{amText}}, or a list with two
 #'   fields: \code{text}, a list of settings created with \code{\link{amText}},
 #'   and \code{align}, can be \code{"left"}, \code{"right"} or \code{"center"}
-#' @param theme theme, \code{NULL} or one of \code{"dataviz"},
-#'   \code{"material"}, \code{"kelly"}, \code{"dark"}, \code{"moonrisekingdom"},
-#'   \code{"frozen"}, \code{"spiritedaway"}, \code{"patterns"},
-#'   \code{"microchart"}
+#' @template themeTemplate
 #' @param draggable \code{TRUE}/\code{FALSE} to enable/disable dragging of
 #'   all lines, otherwise a named list of the form
 #'   \code{list(yvalue1 = TRUE, yvalue2 = FALSE, ...)} to enable/disable the
@@ -369,6 +366,7 @@ amLineChart <- function(
   trend = FALSE,
   chartTitle = NULL,
   theme = NULL,
+  animated = TRUE,
   draggable = FALSE,
   tooltip = NULL, # default
   bullets = NULL, # default
@@ -1109,6 +1107,7 @@ amLineChart <- function(
       Yformatter = Yformatter,
       chartTitle = chartTitle,
       theme = theme,
+      animated = animated,
       draggable = draggable,
       tooltip = tooltip,
       bullets = bullets,
